@@ -14,11 +14,16 @@ for (algorithm in algorithms) {
   test_that(paste(attr(algorithm(),'name')," columns number are correct"), {
     expect_equal(ncol(result$bestFeatures), ncol(iris) - 1)
   })
-  test_that(paste(attr(algorithm(),'name')," fitness value is in correct range"), {
-    expect_true(all(result$bestFitness <= 1))
-    expect_true(all(result$bestFitness >= 0))
-  })
   test_that(paste(attr(algorithm(),'name')," stops if an individual measure is used"), {
     expect_error(algorithm()(iris, 'Species', relief()), 'Only feature set measures can be used')
   })
+  test_that(paste(attr(algorithm(), 'name'), " fitness value is in correct range"), {
+    eps <- if (capabilities("long.double")) {
+      expect_true(all(result$bestFitness <= 1))
+      expect_true(all(result$bestFitness >= 0))
+    } else {
+      expect_true(all(result$bestFitness <= 1.1))
+      expect_true(all(result$bestFitness >= -0.1))
+    }
+  })
 }
